#[repr(u32)]pub enum RequestNameReply {
PrimaryOwner = 1,
InQueue = 2,
Exists = 3,
AlreadyOwner = 4,
}Expand description
The return code of the DBusProxy::request_name method.
Variants
PrimaryOwner = 1
The caller is now the primary owner of the name, replacing any previous owner. Either the
name had no owner before, or the caller specified RequestNameFlags::ReplaceExisting and
the current owner specified RequestNameFlags::AllowReplacement.
InQueue = 2
The name already had an owner, RequestNameFlags::DoNotQueue was not specified, and
either the current owner did not specify RequestNameFlags::AllowReplacement or the
requesting application did not specify RequestNameFlags::ReplaceExisting.
Exists = 3
The name already had an owner, RequestNameFlags::DoNotQueue was specified, and either
RequestNameFlags::AllowReplacement was not specified by the current owner, or
RequestNameFlags::ReplaceExisting was not specified by the requesting application.
AlreadyOwner = 4
The application trying to request ownership of a name is already the owner of it.